
Welcome to the fRAGme documentation!
======================================

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-line: 4

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   docker
   environment